@@ -575,16 +575,23 @@ class Archipelagos:
                 bytes_io = io.BytesIO(response.file)
                 file_name = response.metadata.name.lower()
 
+                # Process the data in the response object
+
                 if file_name.endswith(".csv"):
-                    return pd.read_csv(bytes_io)
+                    df = pd.read_csv(bytes_io)
                 elif file_name.endswith(".parquet"):
-                    return pd.read_parquet(bytes_io)
+                    df = pd.read_parquet(bytes_io)
                 elif file_name.endswith(".json"):
-                    return pd.read_json(bytes_io)
+                    df = pd.read_json(bytes_io)
                 elif file_name.endswith(".xls") or file_name.endswith(".xlsx"):
-                    return pd.read_excel(bytes_io)
+                    df = pd.read_excel(bytes_io)
                 else:
-                    return pd.read_table(bytes_io)
+                    df = pd.read_table(bytes_io)
+
+                # Add the file metadata and return
+
+                df.metadata = response.metadata
+                return df
         else:
             raise ValueError('response is of an unsupported type')
 
@@ -700,10 +707,14 @@ class Archipelagos:
                 if file_name.endswith(".json") or file_name.endswith(".geojson"):
                     bytes_io = io.BytesIO(response.file)
                     file = io.TextIOWrapper(bytes_io, encoding='utf-8')
-                    return gpd.read_file(file)
+                    df = gpd.read_file(file)
+                    df.metadata = response.metadata
+                    return df
 
                 else:
-                    return gpd.read_file(io.BytesIO(response.file))
+                    df = gpd.read_file(io.BytesIO(response.file))
+                    df.metadata = response.metadata
+                    return df
         else:
             raise ValueError('response is of an unsupported type')
 
