@@ -491,40 +491,83 @@ def _get_feature_value_from_proto(feature_value_proto: DataEntry_pb2.DataEntry)
         raise ValueError("Unrecognised entry type")
 
 
-class DataId:
+class DataType(Enum):
     """
-    Represents the ID for an item of data.
+    The different types of data that may be stored in the platform.
+    """
+    TIME_SERIES = 0
+    COLLECTION = 1
+    FILE_STORE = 2
+
+
+def get_data_type_display_str(data_type: DataType) -> str:
+    """
+    Returns the str that should be used to display a DataType.
+
+    :param data_type: The data type.
+    :type data_type: DataType
+
+    :return: str that should be used to display a DataType.
+    :rtype: str
+    """
+    if isinstance(data_type, DataType):
+        if data_type == DataType.TIME_SERIES:
+            return "time-series"
+
+        elif data_type == DataType.COLLECTION:
+            return "collection"
+
+        elif data_type == DataType.FILE_STORE:
+            return "file store"
+
+        else:
+            return ""
+    else:
+        return ""
+
+
+class DatasetId:
+    """
+    Represents the ID for a dataset.
     """
     def __init__(self,
+                 data_type: DataType,
                  source: str,
-                 code: str,
-                 did: str):
+                 category: str,
+                 label: str):
         """
-        :param source: The source for the data.
+        :param data_type: The DataType for the dataset.
+        :type data_type: DataType
+
+        :param source: The source for the dataset.
         :type source: str
 
-        :param code: The code for the data.
-        :type code: str
+        :param category: The category for the dataset.
+        :type category: str
 
-        :param did: The ID for the data.
-        :type did: str
+        :param label: The label for the dataset.
+        :type label: str
         """
         # Check the arguments
 
+        if not isinstance(data_type, DataType):
+            raise ValueError(f'The data type "{data_type}" is not valid')
+
         if not is_valid_token(source):
             raise ValueError(f'The source "{source}" is not a valid token')
 
-        if not is_valid_token(code):
-            raise ValueError(f'The code "{code}" is not a valid token')
+        if not is_valid_token(category):
+            raise ValueError(f'The category "{category}" is not a valid token')
 
-        if not is_valid_token(did):
-            raise ValueError(f'The did "{did}" is not a valid token')
+        if not is_valid_token(label):
+            raise ValueError(f'The label "{label}" is not a valid token')
 
         # Create the object
 
+        self._data_type = data_type
         self._source = source
-        self._code = code
-        self._id = did
+        self._category = category
+        self._label = label
 
         self._hash_code = 0
         self._build_hash_code()
@@ -535,11 +578,19 @@ class DataId:
         """
         prime = 31
         result = 1
+        result = prime * result + (0 if self._source is None else hash(self._data_type.name))
         result = prime * result + (0 if self._source is None else hash(self._source))
-        result = prime * result + (0 if self._code is None else hash(self._code))
-        result = prime * result + (0 if self._id is None else hash(self._id))
+        result = prime * result + (0 if self._category is None else hash(self._category))
+        result = prime * result + (0 if self._label is None else hash(self._label))
         self._hash_code = result
 
+    @property
+    def data_type(self) -> DataType:
+        """
+        The DataType for the data.
+        """
+        return self._data_type
+
     @property
     def source(self) -> str:
         """
@@ -548,23 +599,30 @@ class DataId:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        The code for the data.
+        The category for the data.
         """
-        return self._code
+        return self._category
 
     @property
-    def id(self) -> str:
+    def label(self) -> str:
         """
-        The ID for the data.
+        The label for the data.
         """
-        return self._id
+        return self._label
 
     def __eq__(self, other):
         """
         """
-        if other is DataId:
+        if other is DatasetId:
+            if self._data_type is None:
+                if other.data_type is None:
+                    return False
+            else:
+                if self._data_type != other.data_type:
+                    return False
+
             if self._source is None:
                 if other.source is None:
                     return False
@@ -572,18 +630,18 @@ class DataId:
                 if self._source != other.source:
                     return False
 
-            if self._code is None:
+            if self._category is None:
                 if other.category is None:
                     return False
             else:
-                if self._code != other.category:
+                if self._category != other.category:
                     return False
 
-            if self._id is None:
-                if other.id is None:
+            if self._label is None:
+                if other.label is None:
                     return False
             else:
-                if self._id != other.id:
+                if self._label != other.label:
                     return False
 
             return True
@@ -601,12 +659,14 @@ class DataId:
         """
         to_return = ""
 
+        to_return += "DataType = \""
+        to_return += self._data_type
         to_return += "Source = \""
         to_return += self._source
-        to_return += "\", Code = \""
-        to_return += self._code
-        to_return += "\", ID = \""
-        to_return += self._id
+        to_return += "\", Category = \""
+        to_return += self._category
+        to_return += "\", Label = \""
+        to_return += self._label
         to_return += "\""
 
         return to_return
@@ -634,15 +694,6 @@ def parse_bool_str(value: str) -> bool:
         raise ValueError(f"Unrecognised str '{value}'")
 
 
-class DataType(Enum):
-    """
-    The different types of data that may be stored in the platform.
-    """
-    TIME_SERIES = 0
-    COLLECTION = 1
-    FILE_STORE = 2
-
-
 class DataProperties:
     """
     The (optional) properties that a dataset (time-series, collection, file store...) may have.
