@@ -321,9 +321,8 @@ class CollectionMetadata:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         metadata = CollectionMetadata_pb2.CollectionMetadata()
-        metadata.ParseFromString(byte_array)
+        metadata.ParseFromString(serialized)
         self._read_proto_object(metadata)
 
     def _read_proto_object(self, metadata: CollectionMetadata_pb2.CollectionMetadata):
@@ -581,9 +580,8 @@ class CollectionData:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         collection_data = CollectionData_pb2.CollectionData()
-        collection_data.ParseFromString(byte_array)
+        collection_data.ParseFromString(serialized)
         self._read_proto_object(collection_data)
 
     def _read_proto_object(self,
@@ -737,9 +735,8 @@ class Collection:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         collection = Collection_pb2.Collection()
-        collection.ParseFromString(byte_array)
+        collection.ParseFromString(serialized)
         self._read_proto_object(collection)
 
     def _read_proto_object(self,
@@ -928,9 +925,8 @@ class CollectionMetadataRequest:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         request = CollectionMetadataRequest_pb2.CollectionMetadataRequest()
-        request.ParseFromString(byte_array)
+        request.ParseFromString(serialized)
         self._read_proto_object(request)
 
     def _read_proto_object(self,
@@ -1083,9 +1079,8 @@ class CollectionMetadataResponse:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         response = CollectionMetadataResponse_pb2.CollectionMetadataResponse()
-        response.ParseFromString(byte_array)
+        response.ParseFromString(serialized)
         self._read_proto_object(response)
 
     def _read_proto_object(self,
@@ -1356,9 +1351,8 @@ class CollectionRequest:
         :param serialized : bytes produced by serialize().
         :type serialized : str or bytes
         """
-        byte_array = array.array('B', serialized)
         request = CollectionRequest_pb2.CollectionRequest()
-        request.ParseFromString(byte_array)
+        request.ParseFromString(serialized)
         self._read_proto_object(request)
 
     def _read_proto_object(self,
@@ -1530,9 +1524,8 @@ class CollectionResponse:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         response = CollectionResponse_pb2.CollectionResponse()
-        response.ParseFromString(byte_array)
+        response.ParseFromString(serialized)
         self._read_proto_object(response)
 
     def _read_proto_object(self, response: CollectionResponse_pb2.CollectionResponse):
