@@ -17,7 +17,6 @@ from archipelagos.common.data import is_valid_token
 
 from pandas import Timestamp
 from typing import List, Dict
-import array
 
 
 class FileStoreMetadata:
@@ -386,6 +385,8 @@ class FileMetadata:
                  name: str,
                  size: int,
                  premium: bool,
+                 properties: Dict[str, str] = None,
+                 features: Dict[str, str] = None,
                  created: Timestamp = None):
         """
         All parameters should be supplied unless deserializing an object.
@@ -408,6 +409,12 @@ class FileMetadata:
         :param premium: True if the file is premium, False otherwise.
         :type premium: bool
 
+        :param properties: The file's properties.
+        :type properties: Dict[str, str]
+
+        :param features: Dict[str, str]
+        :type features: The file's features and their descriptions.
+
         :param created: When (in UTC) the file was created.
         :type created: Timestamp
         """
@@ -440,10 +447,32 @@ class FileMetadata:
         if not isinstance(premium, bool):
             raise ValueError("premium is not a valid bool")
 
+        if properties is None:
+            properties = {}
+        elif not isinstance(properties, dict):
+            raise ValueError("properties is not a dict")
+
+        for key, value in properties.items():
+            if not isinstance(key, str):
+                raise ValueError(f"properties contains a key ({key}) that is not a str")
+            if not isinstance(value, str):
+                raise ValueError(f"properties contains a value ({value}) that is not a str")
+
+        if features is None:
+            features = {}
+        elif not isinstance(features, dict):
+            raise ValueError("features is not a dict")
+
+        for key, value in features.items():
+            if not isinstance(key, str):
+                raise ValueError(f"features contains a key ({key}) that is not a str")
+            if not isinstance(value, str):
+                raise ValueError(f"features contains a value ({value}) that is not a str")
+
         if not isinstance(created, Timestamp):
             raise ValueError("created is not a valid Timestamp")
 
-        # Store the data
+    # Store the data
 
         self._source = source
         self._category = category
@@ -451,6 +480,8 @@ class FileMetadata:
         self._name = name
         self._size = size
         self._premium = premium
+        self._properties = properties
+        self._features = features
         self._created = created
 
         self._build_hash_code()
@@ -530,6 +561,26 @@ class FileMetadata:
         """
         return self._premium
 
+    @property
+    def properties(self) -> Dict[str, str]:
+        """
+        The file's properties.
+
+        :return: The file's properties.
+        :rtype Dict[str, str]
+        """
+        return self._properties
+
+    @property
+    def features(self) -> Dict[str, str]:
+        """
+        The file's features.
+
+        :return: The file's features.
+        :rtype Dict[str, str]
+        """
+        return self._features
+
     @property
     def created(self) -> Timestamp:
         """
@@ -551,7 +602,7 @@ class FileMetadata:
         :return: A new instance using bytes created by serialize().
         :rtype: FileMetadata
         """
-        metadata = FileMetadata("a", "a", "a", "", 0, False, Timestamp.now())
+        metadata = FileMetadata("a", "a", "a", "", 0, False, dict(), dict(), Timestamp.now())
         metadata._read_proto(serialized)
         return metadata
 
@@ -581,6 +632,14 @@ class FileMetadata:
         self._size = metadata.size
         self._premium = metadata.premium
 
+        self._properties = dict()
+        for key in metadata.properties:
+            self._properties[key] = metadata.properties[key]
+
+        self._features = dict()
+        for key in metadata.features:
+            self._features[key] = metadata.features[key]
+
         timestamp = metadata.created
         self._created = get_timestamp(timestamp.epochSecond, timestamp.nanosecond)
 
@@ -601,6 +660,12 @@ class FileMetadata:
         metadata.size = self._size
         metadata.premium = self._premium
 
+        for key, value in self._properties.items():
+            metadata.properties[key] = value
+
+        for key, value in self._features.items():
+            metadata.features[key] = value
+
         timestamp = Timestamp_pb2.Timestamp()
         timestamp.epochSecond = get_secs_from_timestamp(self._created)
         timestamp.nanosecond = get_nanos_from_timestamp(self._created)
@@ -654,6 +719,8 @@ class FileMetadata:
                "Name = " + self._name + \
                "Size = " + str(self._size) + \
                "Premium = " + str(self._premium) + \
+               "Properties = " + str(self._properties) + \
+               "Features = " + str(self._features) + \
                "Created = " + get_yyyy_mm_dd_hh_mm_ss_n(self._created)
 
 
@@ -1368,7 +1435,7 @@ class FileStoreResponse:
         else:
             self._error_code = 0
             self._error_message = None
-            self._metadata = FileMetadata("a", "a", "a", "a", 0, False, Timestamp.now())
+            self._metadata = FileMetadata("a", "a", "a", "a", 0, False, dict(), dict(), Timestamp.now())
             self._metadata._read_proto_object(response.metadata)
             self._file = response.file
 
@@ -1758,7 +1825,7 @@ class FileMetadataResponse:
             self._metadata = list()
 
             for file_metadata_proto in response.metadata:
-                file_metadata = FileMetadata("a", "a", "a", "", 0, False, Timestamp.now())
+                file_metadata = FileMetadata("a", "a", "a", "", 0, False, dict(), dict(), Timestamp.now())
                 file_metadata._read_proto_object(file_metadata_proto)
                 self._metadata.append(file_metadata)
 
